@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: blaze-builder
 version: 0.4.0.1
-id: blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
-key: blaze_GoSGMrJXTmeEBoF3sgxwrM
+id: blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
+key: blaze_4KI2nf4lf9oHEgXiILyTYj
 license: BSD3
 copyright: (c) 2010-2014 Simon Meier
            (c) 2010 Jasper Van der Jeugt
@@ -42,12 +42,12 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-builder-0.4.0.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/blaze-builder-0.4.0.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/blaze-builder-0.4.0.1
-hs-libraries: HSblaze-builder-0.4.0.1-GoSGMrJXTmeEBoF3sgxwrM
+hs-libraries: HSblaze-builder-0.4.0.1-4KI2nf4lf9oHEgXiILyTYj
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
 haddock-interfaces: /usr/share/doc/haskell-blaze-builder/html/blaze-builder.haddock
 haddock-html: /usr/share/doc/haskell-blaze-builder/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
